@@ -43,13 +43,10 @@ from neutron.api.rpc.callbacks import events as rpc_events
 from neutron.api.rpc.handlers import resources_rpc
 from neutron.conf.agent import common as config
 from neutron.conf.plugins.ml2.drivers import ovs_conf
-from neutron.debug import debug_agent
 from neutron.plugins.ml2.drivers.linuxbridge.agent.common \
     import constants as lnxbridge_agt_constants
 from neutron.plugins.ml2.drivers.linuxbridge.agent import \
     linuxbridge_neutron_agent as lnx_agt
-from neutron.plugins.ml2.drivers.openvswitch.agent.common \
-    import constants as ovs_agt_consts
 from neutron.plugins.ml2.drivers.openvswitch.agent import vlanmanager
 
 from neutron_lib.agent import l2_extension
@@ -59,6 +56,7 @@ from neutron_lib.callbacks import events
 from neutron_lib.callbacks import registry
 from neutron_lib.callbacks import resources
 from neutron_lib import constants as n_const
+from neutron_lib.plugins.ml2 import ovs_constants as ovs_agt_consts
 
 LOG = logging.getLogger(__name__)
 
@@ -478,9 +476,7 @@ class BagpipeBgpvpnAgentExtension(l2_extension.L2AgentExtension,
             return True
 
         if (data['device_owner'].startswith(
-            n_const.DEVICE_OWNER_NETWORK_PREFIX) and not (data['device_owner']
-            in (debug_agent.DEVICE_OWNER_COMPUTE_PROBE,
-                debug_agent.DEVICE_OWNER_NETWORK_PROBE))):
+                n_const.DEVICE_OWNER_NETWORK_PREFIX)):
             LOG.info("Port %s owner is network:*, we'll do nothing",
                      data['port_id'])
             return True
@@ -674,7 +670,8 @@ class BagpipeBgpvpnAgentExtension(l2_extension.L2AgentExtension,
         # to each specific router MAC to br-mpls
 
         try:
-            vlan = self.vlan_manager.get(net_info.id).vlan
+            vlan = self.vlan_manager.get(net_info.id,
+                                         net_info.segmentation_id).vlan
 
             if net_info.gateway_info.mac:
                 # there is a Neutron router on this network, so we won't
@@ -746,7 +743,8 @@ class BagpipeBgpvpnAgentExtension(l2_extension.L2AgentExtension,
             return
 
         try:
-            vlan = self.vlan_manager.get(net_info.id).vlan
+            vlan = self.vlan_manager.get(net_info.id,
+                                         net_info.segmentation_id).vlan
             if net_info.gateway_info.ip:
                 self._disable_gw_arp_responder(vlan, net_info.gateway_info.ip)
             else:
@@ -772,7 +770,8 @@ class BagpipeBgpvpnAgentExtension(l2_extension.L2AgentExtension,
         }
 
         if self._is_ovs_extension():
-            vlan = self.vlan_manager.get(port_info.network.id).vlan
+            vlan = self.vlan_manager.get(
+                port_info.network.id, port_info.network.segmentation_id).vlan
             i['local_port']['linuxif'] = (
                 '%s:%s' % (bgpvpn_const.LINUXIF_PREFIX, vlan))
         else:
@@ -829,7 +828,8 @@ class BagpipeBgpvpnAgentExtension(l2_extension.L2AgentExtension,
 
         if self._is_ovs_extension():
             # Add OVS VLAN information
-            vlan = self.vlan_manager.get(net_info.id).vlan
+            vlan = self.vlan_manager.get(net_info.id,
+                                         net_info.segmentation_id).vlan
 
             if bbgp_vpn_type == bbgp_const.EVPN:
                 attach_info['local_port']['vlan'] = vlan
