@@ -18,6 +18,7 @@ from netaddr.ip import IPNetwork
 
 from neutron_lib.api.definitions import bgpvpn as bgpvpn_def
 from neutron_lib.api.definitions import provider_net as pnet
+from neutron_lib.db import api as db_api
 from neutron_lib.db import model_query
 from neutron_lib.plugins import directory
 
@@ -220,6 +221,7 @@ class BaGPipeSfcDriver(driver_base.SfcDriverBase,
 
         return ports
 
+    @db_api.CONTEXT_WRITER
     def _has_valid_port_pair_groups(self, context, ppg_ids):
         for ppg_id in ppg_ids:
             ppg = context._plugin._get_port_pair_group(context._plugin_context,
@@ -230,6 +232,7 @@ class BaGPipeSfcDriver(driver_base.SfcDriverBase,
 
         return True
 
+    @db_api.CONTEXT_WRITER
     def _is_valid_port_chain(self, context, port_chain):
         """Verify Port Chain consistency for BaGPipe
 
@@ -255,6 +258,7 @@ class BaGPipeSfcDriver(driver_base.SfcDriverBase,
         return True
 
     @log_helpers.log_method_call
+    @db_api.CONTEXT_WRITER
     def _create_portchain_hop_details(self, context, port_chain,
                                       reverse=False):
         project_id = port_chain['tenant_id']
@@ -531,6 +535,7 @@ class BaGPipeSfcDriver(driver_base.SfcDriverBase,
 
         return hop_details
 
+    @db_api.CONTEXT_WRITER
     def _create_portchain_hops(self, context, port_chain):
         symmetric = port_chain['chain_parameters'].get('symmetric')
 
@@ -547,6 +552,7 @@ class BaGPipeSfcDriver(driver_base.SfcDriverBase,
                                 rpc_events.CREATED)
 
     @log_helpers.log_method_call
+    @db_api.CONTEXT_WRITER
     def create_port_chain(self, context):
         port_chain = context.current
 
@@ -556,24 +562,25 @@ class BaGPipeSfcDriver(driver_base.SfcDriverBase,
         self._create_portchain_hops(context, port_chain)
 
     def _delete_portchain_hops(self, context, port_chain):
-        # Release PPG route targets
-        for ppg_id in port_chain['port_pair_groups']:
-            ppg_rtnns = self.rt_allocator.get_rts_by_ppg(ppg_id)
+        with db_api.CONTEXT_WRITER.using(context):
+            # Release PPG route targets
+            for ppg_id in port_chain['port_pair_groups']:
+                ppg_rtnns = self.rt_allocator.get_rts_by_ppg(ppg_id)
 
-            if ppg_rtnns:
-                for rtnn in ppg_rtnns:
-                    self.rt_allocator.release_rt(rtnn)
+                if ppg_rtnns:
+                    for rtnn in ppg_rtnns:
+                        self.rt_allocator.release_rt(rtnn)
 
-        hop_objs = sfc_obj.BaGPipeChainHop.get_objects(
-            context._plugin_context,
-            portchain_id=port_chain['id'])
+            hop_objs = sfc_obj.BaGPipeChainHop.get_objects(
+                context._plugin_context,
+                portchain_id=port_chain['id'])
 
-        if hop_objs:
-            for hop_obj in hop_objs:
-                hop_obj.delete()
+            if hop_objs:
+                for hop_obj in hop_objs:
+                    hop_obj.delete()
 
-            self._push_rpc.push(context._plugin_context, hop_objs,
-                                rpc_events.DELETED)
+                self._push_rpc.push(context._plugin_context, hop_objs,
+                                    rpc_events.DELETED)
 
     @log_helpers.log_method_call
     def delete_port_chain(self, context):
@@ -582,6 +589,7 @@ class BaGPipeSfcDriver(driver_base.SfcDriverBase,
         self._delete_portchain_hops(context, port_chain)
 
     @log_helpers.log_method_call
+    @db_api.CONTEXT_WRITER
     def update_port_chain(self, context):
         current = context.current
         original = context.original
@@ -614,6 +622,7 @@ class BaGPipeSfcDriver(driver_base.SfcDriverBase,
 
             self._create_portchain_hops(context, current)
 
+    @db_api.CONTEXT_WRITER
     def _has_valid_port_pairs(self, context):
         port_pair_group = context._plugin._get_port_pair_group(
             context._plugin_context,
@@ -653,6 +662,7 @@ class BaGPipeSfcDriver(driver_base.SfcDriverBase,
         pass
 
     @log_helpers.log_method_call
+    @db_api.CONTEXT_WRITER
     def update_port_pair_group(self, context):
         current = context.current
         original = context.original
